pub fn load_from(path: PathBuf) -> Result<(), String>Expand description
Load all of the function definitions from a shared library at the given path.
This is useful when the library is not in a standard location and cannot be
discovered by the openvino-finder search paths. The path should point to
the openvino_c shared library file (e.g., libopenvino_c.so).
If the library has already been loaded (e.g., via load), this is a no-op.
Errors
May fail if the shared library cannot be opened or is invalid.